/****************************************************************************
** Resource object code
**
** Created by: The Resource Compiler for Qt version 6.11.1
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#ifdef _MSC_VER
// disable informational message "function ... selected for automatic inline expansion"
#pragma warning (disable: 4711)
#endif

static const unsigned char qt_resource_data[] = {
  // main.qml
  0x0,0x0,0x1,0x4e,
  0x2f,
  0x2a,0xa,0x20,0x20,0x20,0x20,0x53,0x50,0x44,0x58,0x2d,0x4c,0x69,0x63,0x65,0x6e,
  0x73,0x65,0x2d,0x49,0x64,0x65,0x6e,0x74,0x69,0x66,0x69,0x65,0x72,0x3a,0x20,0x47,
  0x50,0x4c,0x2d,0x32,0x2e,0x30,0x2d,0x6f,0x6e,0x6c,0x79,0x20,0x4f,0x52,0x20,0x47,
  0x50,0x4c,0x2d,0x33,0x2e,0x30,0x2d,0x6f,0x6e,0x6c,0x79,0x20,0x4f,0x52,0x20,0x4c,
  0x69,0x63,0x65,0x6e,0x73,0x65,0x52,0x65,0x66,0x2d,0x4b,0x44,0x45,0x2d,0x41,0x63,
  0x63,0x65,0x70,0x74,0x65,0x64,0x2d,0x47,0x50,0x4c,0xa,0x20,0x20,0x20,0x20,0x53,
  0x50,0x44,0x58,0x2d,0x46,0x69,0x6c,0x65,0x43,0x6f,0x70,0x79,0x72,0x69,0x67,0x68,
  0x74,0x54,0x65,0x78,0x74,0x3a,0x20,0x32,0x30,0x32,0x31,0x20,0x48,0x61,0x72,0x61,
  0x6c,0x64,0x20,0x53,0x69,0x74,0x74,0x65,0x72,0x20,0x3c,0x73,0x69,0x74,0x74,0x65,
  0x72,0x40,0x6b,0x64,0x65,0x2e,0x6f,0x72,0x67,0x3e,0xa,0x2a,0x2f,0xa,0xa,0x69,
  0x6d,0x70,0x6f,0x72,0x74,0x20,0x51,0x74,0x51,0x75,0x69,0x63,0x6b,0x20,0x32,0x2e,
  0x35,0xa,0xa,0x69,0x6d,0x70,0x6f,0x72,0x74,0x20,0x6f,0x72,0x67,0x2e,0x6b,0x64,
  0x65,0x2e,0x6b,0x63,0x6d,0x75,0x74,0x69,0x6c,0x73,0x20,0x61,0x73,0x20,0x4b,0x43,
  0x4d,0xa,0xa,0x69,0x6d,0x70,0x6f,0x72,0x74,0x20,0x6f,0x72,0x67,0x2e,0x6b,0x64,
  0x65,0x2e,0x6b,0x69,0x6e,0x66,0x6f,0x63,0x65,0x6e,0x74,0x65,0x72,0x2e,0x70,0x72,
  0x69,0x76,0x61,0x74,0x65,0x20,0x31,0x2e,0x30,0x20,0x61,0x73,0x20,0x4b,0x49,0x6e,
  0x66,0x6f,0x43,0x65,0x6e,0x74,0x65,0x72,0xa,0xa,0x4b,0x49,0x6e,0x66,0x6f,0x43,
  0x65,0x6e,0x74,0x65,0x72,0x2e,0x43,0x6f,0x6d,0x6d,0x61,0x6e,0x64,0x4f,0x75,0x74,
  0x70,0x75,0x74,0x4b,0x43,0x4d,0x20,0x7b,0xa,0x20,0x20,0x20,0x20,0x6f,0x75,0x74,
  0x70,0x75,0x74,0x3a,0x20,0x6b,0x63,0x6d,0x2e,0x69,0x6e,0x66,0x6f,0x4f,0x75,0x74,
  0x70,0x75,0x74,0x43,0x6f,0x6e,0x74,0x65,0x78,0x74,0xa,0x7d,0xa,
  
};

static const unsigned char qt_resource_name[] = {
  // kcm
  0x0,0x3,
  0x0,0x0,0x71,0x9d,
  0x0,0x6b,
  0x0,0x63,0x0,0x6d,
    // kcm_egl
  0x0,0x7,
  0x1,0xa3,0x5b,0x3c,
  0x0,0x6b,
  0x0,0x63,0x0,0x6d,0x0,0x5f,0x0,0x65,0x0,0x67,0x0,0x6c,
    // main.qml
  0x0,0x8,
  0x8,0x1,0x5a,0x5c,
  0x0,0x6d,
  0x0,0x61,0x0,0x69,0x0,0x6e,0x0,0x2e,0x0,0x71,0x0,0x6d,0x0,0x6c,
  
};

static const unsigned char qt_resource_struct[] = {
  // :
  0x0,0x0,0x0,0x0,0x0,0x2,0x0,0x0,0x0,0x1,0x0,0x0,0x0,0x1,
0x0,0x0,0x1,0x9f,0x19,0x7b,0xba,0xd8,
  // :/kcm
  0x0,0x0,0x0,0x0,0x0,0x2,0x0,0x0,0x0,0x1,0x0,0x0,0x0,0x2,
0x0,0x0,0x1,0x9f,0x19,0x7b,0xba,0xd8,
  // :/kcm/kcm_egl
  0x0,0x0,0x0,0xc,0x0,0x2,0x0,0x0,0x0,0x1,0x0,0x0,0x0,0x3,
0x0,0x0,0x1,0x9f,0x19,0x7b,0xba,0xd8,
  // :/kcm/kcm_egl/main.qml
  0x0,0x0,0x0,0x20,0x0,0x0,0x0,0x0,0x0,0x1,0x0,0x0,0x0,0x0,
0x0,0x0,0x1,0x9f,0x19,0x7b,0xba,0xd8,

};

#ifdef QT_NAMESPACE
#  define QT_RCC_PREPEND_NAMESPACE(name) ::QT_NAMESPACE::name
#  define QT_RCC_MANGLE_NAMESPACE0(x) x
#  define QT_RCC_MANGLE_NAMESPACE1(a, b) a##_##b
#  define QT_RCC_MANGLE_NAMESPACE2(a, b) QT_RCC_MANGLE_NAMESPACE1(a,b)
#  define QT_RCC_MANGLE_NAMESPACE(name) QT_RCC_MANGLE_NAMESPACE2( \
        QT_RCC_MANGLE_NAMESPACE0(name), QT_RCC_MANGLE_NAMESPACE0(QT_NAMESPACE))
#else
#   define QT_RCC_PREPEND_NAMESPACE(name) name
#   define QT_RCC_MANGLE_NAMESPACE(name) name
#endif

#if defined(QT_INLINE_NAMESPACE)
inline namespace QT_NAMESPACE {
#elif defined(QT_NAMESPACE)
namespace QT_NAMESPACE {
#endif

bool qRegisterResourceData(int, const unsigned char *, const unsigned char *, const unsigned char *);
bool qUnregisterResourceData(int, const unsigned char *, const unsigned char *, const unsigned char *);

#ifdef QT_NAMESPACE
}
#endif

int QT_RCC_MANGLE_NAMESPACE(qInitResources_kcm_egl)();
int QT_RCC_MANGLE_NAMESPACE(qInitResources_kcm_egl)()
{
    int version = 3;
    QT_RCC_PREPEND_NAMESPACE(qRegisterResourceData)
        (version, qt_resource_struct, qt_resource_name, qt_resource_data);
    return 1;
}

int QT_RCC_MANGLE_NAMESPACE(qCleanupResources_kcm_egl)();
int QT_RCC_MANGLE_NAMESPACE(qCleanupResources_kcm_egl)()
{
    int version = 3;
    QT_RCC_PREPEND_NAMESPACE(qUnregisterResourceData)
       (version, qt_resource_struct, qt_resource_name, qt_resource_data);
    return 1;
}

#ifdef __clang__
#   pragma clang diagnostic push
#   pragma clang diagnostic ignored "-Wexit-time-destructors"
#endif

namespace {
   struct initializer {
       initializer() { QT_RCC_MANGLE_NAMESPACE(qInitResources_kcm_egl)(); }
       ~initializer() { QT_RCC_MANGLE_NAMESPACE(qCleanupResources_kcm_egl)(); }
   } dummy;
}

#ifdef __clang__
#   pragma clang diagnostic pop
#endif
