/****************************************************************************
** Meta object code from reading C++ file 'Entry.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.1)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../../../kinfocenter-6.7.2/kcms/about-distro/src/Entry.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'Entry.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.1. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN4HintE_t {};
} // unnamed namespace

template <> constexpr inline auto Hint::qt_create_metaobjectdata<qt_meta_tag_ZN4HintE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "Hint",
        "text",
        "color",
        "Color",
        "One",
        "Two",
        "Three"
    };

    QtMocHelpers::UintData qt_methods {
    };
    QtMocHelpers::UintData qt_properties {
        // property 'text'
        QtMocHelpers::PropertyData<QString>(1, QMetaType::QString, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'color'
        QtMocHelpers::PropertyData<enum Color>(2, 0x80000000 | 3, QMC::DefaultPropertyFlags | QMC::EnumOrFlag | QMC::Constant),
    };
    QtMocHelpers::UintData qt_enums {
        // enum 'Color'
        QtMocHelpers::EnumData<enum Color>(3, 3, QMC::EnumIsScoped).add({
            {    4, Color::One },
            {    5, Color::Two },
            {    6, Color::Three },
        }),
    };
    return QtMocHelpers::metaObjectData<Hint, qt_meta_tag_ZN4HintE_t>(QMC::PropertyAccessInStaticMetaCall, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject Hint::staticMetaObject = { {
    nullptr,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN4HintE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN4HintE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN4HintE_t>.metaTypes,
    nullptr
} };

void Hint::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = reinterpret_cast<Hint *>(_o);
    if (_c == QMetaObject::ReadProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: *reinterpret_cast<QString*>(_v) = _t->m_text; break;
        case 1: *reinterpret_cast<enum Color*>(_v) = _t->m_color; break;
        default: break;
        }
    }
}
namespace {
struct qt_meta_tag_ZN5EntryE_t {};
} // unnamed namespace

template <> constexpr inline auto Entry::qt_create_metaobjectdata<qt_meta_tag_ZN5EntryE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "Entry",
        "localizedLabel",
        "",
        "Language",
        "language",
        "localizedValue",
        "isHidden",
        "localizedHint",
        "Hint",
        "localizedHelp",
        "System",
        "English",
        "Hidden",
        "No",
        "Yes"
    };

    QtMocHelpers::UintData qt_methods {
        // Method 'localizedLabel'
        QtMocHelpers::MethodData<QString(enum Language) const>(1, 2, QMC::AccessPublic, QMetaType::QString, {{
            { 0x80000000 | 3, 4 },
        }}),
        // Method 'localizedLabel'
        QtMocHelpers::MethodData<QString() const>(1, 2, QMC::AccessPublic | QMC::MethodCloned, QMetaType::QString),
        // Method 'localizedValue'
        QtMocHelpers::MethodData<QString(enum Language) const>(5, 2, QMC::AccessPublic, QMetaType::QString, {{
            { 0x80000000 | 3, 4 },
        }}),
        // Method 'localizedValue'
        QtMocHelpers::MethodData<QString() const>(5, 2, QMC::AccessPublic | QMC::MethodCloned, QMetaType::QString),
        // Method 'isHidden'
        QtMocHelpers::MethodData<bool() const>(6, 2, QMC::AccessPublic, QMetaType::Bool),
        // Method 'localizedHint'
        QtMocHelpers::MethodData<Hint(enum Language) const>(7, 2, QMC::AccessPublic, 0x80000000 | 8, {{
            { 0x80000000 | 3, 4 },
        }}),
        // Method 'localizedHint'
        QtMocHelpers::MethodData<Hint() const>(7, 2, QMC::AccessPublic | QMC::MethodCloned, 0x80000000 | 8),
        // Method 'localizedHelp'
        QtMocHelpers::MethodData<QString(enum Language) const>(9, 2, QMC::AccessPublic, QMetaType::QString, {{
            { 0x80000000 | 3, 4 },
        }}),
        // Method 'localizedHelp'
        QtMocHelpers::MethodData<QString() const>(9, 2, QMC::AccessPublic | QMC::MethodCloned, QMetaType::QString),
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
        // enum 'Language'
        QtMocHelpers::EnumData<enum Language>(3, 3, QMC::EnumIsScoped).add({
            {   10, Language::System },
            {   11, Language::English },
        }),
        // enum 'Hidden'
        QtMocHelpers::EnumData<enum Hidden>(12, 12, QMC::EnumIsScoped).add({
            {   13, Hidden::No },
            {   14, Hidden::Yes },
        }),
    };
    return QtMocHelpers::metaObjectData<Entry, qt_meta_tag_ZN5EntryE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject Entry::staticMetaObject = { {
    QMetaObject::SuperData::link<QObject::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN5EntryE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN5EntryE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN5EntryE_t>.metaTypes,
    nullptr
} };

void Entry::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<Entry *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: { QString _r = _t->localizedLabel((*reinterpret_cast<std::add_pointer_t<enum Language>>(_a[1])));
            if (_a[0]) *reinterpret_cast<QString*>(_a[0]) = std::move(_r); }  break;
        case 1: { QString _r = _t->localizedLabel();
            if (_a[0]) *reinterpret_cast<QString*>(_a[0]) = std::move(_r); }  break;
        case 2: { QString _r = _t->localizedValue((*reinterpret_cast<std::add_pointer_t<enum Language>>(_a[1])));
            if (_a[0]) *reinterpret_cast<QString*>(_a[0]) = std::move(_r); }  break;
        case 3: { QString _r = _t->localizedValue();
            if (_a[0]) *reinterpret_cast<QString*>(_a[0]) = std::move(_r); }  break;
        case 4: { bool _r = _t->isHidden();
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        case 5: { Hint _r = _t->localizedHint((*reinterpret_cast<std::add_pointer_t<enum Language>>(_a[1])));
            if (_a[0]) *reinterpret_cast<Hint*>(_a[0]) = std::move(_r); }  break;
        case 6: { Hint _r = _t->localizedHint();
            if (_a[0]) *reinterpret_cast<Hint*>(_a[0]) = std::move(_r); }  break;
        case 7: { QString _r = _t->localizedHelp((*reinterpret_cast<std::add_pointer_t<enum Language>>(_a[1])));
            if (_a[0]) *reinterpret_cast<QString*>(_a[0]) = std::move(_r); }  break;
        case 8: { QString _r = _t->localizedHelp();
            if (_a[0]) *reinterpret_cast<QString*>(_a[0]) = std::move(_r); }  break;
        default: ;
        }
    }
}

const QMetaObject *Entry::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *Entry::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN5EntryE_t>.strings))
        return static_cast<void*>(this);
    return QObject::qt_metacast(_clname);
}

int Entry::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QObject::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 9)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 9;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 9)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 9;
    }
    return _id;
}
QT_WARNING_POP
