/****************************************************************************
** Meta object code from reading C++ file 'statisticsprovider.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.1)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../../kinfocenter-6.7.2/kcms/energy/statisticsprovider.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'statisticsprovider.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.1. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN18StatisticsProviderE_t {};
} // unnamed namespace

template <> constexpr inline auto StatisticsProvider::qt_create_metaobjectdata<qt_meta_tag_ZN18StatisticsProviderE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "StatisticsProvider",
        "deviceChanged",
        "",
        "typeChanged",
        "durationChanged",
        "dataChanged",
        "historyAvailableChanged",
        "refresh",
        "device",
        "duration",
        "type",
        "HistoryType",
        "points",
        "QVariantList",
        "count",
        "firstDataPointTime",
        "lastDataPointTime",
        "largestValue",
        "available",
        "RateType",
        "ChargeType"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'deviceChanged'
        QtMocHelpers::SignalData<void()>(1, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'typeChanged'
        QtMocHelpers::SignalData<void()>(3, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'durationChanged'
        QtMocHelpers::SignalData<void()>(4, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'dataChanged'
        QtMocHelpers::SignalData<void()>(5, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'historyAvailableChanged'
        QtMocHelpers::SignalData<void()>(6, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'refresh'
        QtMocHelpers::SlotData<void()>(7, 2, QMC::AccessPublic, QMetaType::Void),
    };
    QtMocHelpers::UintData qt_properties {
        // property 'device'
        QtMocHelpers::PropertyData<QString>(8, QMetaType::QString, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 0),
        // property 'duration'
        QtMocHelpers::PropertyData<uint>(9, QMetaType::UInt, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 2),
        // property 'type'
        QtMocHelpers::PropertyData<enum HistoryType>(10, 0x80000000 | 11, QMC::DefaultPropertyFlags | QMC::Writable | QMC::EnumOrFlag | QMC::StdCppSet, 1),
        // property 'points'
        QtMocHelpers::PropertyData<QVariantList>(12, 0x80000000 | 13, QMC::DefaultPropertyFlags | QMC::EnumOrFlag, 3),
        // property 'count'
        QtMocHelpers::PropertyData<int>(14, QMetaType::Int, QMC::DefaultPropertyFlags, 3),
        // property 'firstDataPointTime'
        QtMocHelpers::PropertyData<int>(15, QMetaType::Int, QMC::DefaultPropertyFlags, 3),
        // property 'lastDataPointTime'
        QtMocHelpers::PropertyData<int>(16, QMetaType::Int, QMC::DefaultPropertyFlags, 3),
        // property 'largestValue'
        QtMocHelpers::PropertyData<int>(17, QMetaType::Int, QMC::DefaultPropertyFlags, 3),
        // property 'available'
        QtMocHelpers::PropertyData<bool>(18, QMetaType::Bool, QMC::DefaultPropertyFlags, 4),
    };
    QtMocHelpers::UintData qt_enums {
        // enum 'HistoryType'
        QtMocHelpers::EnumData<enum HistoryType>(11, 11, QMC::EnumFlags{}).add({
            {   19, HistoryType::RateType },
            {   20, HistoryType::ChargeType },
        }),
    };
    return QtMocHelpers::metaObjectData<StatisticsProvider, qt_meta_tag_ZN18StatisticsProviderE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject StatisticsProvider::staticMetaObject = { {
    QMetaObject::SuperData::link<QObject::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN18StatisticsProviderE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN18StatisticsProviderE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN18StatisticsProviderE_t>.metaTypes,
    nullptr
} };

void StatisticsProvider::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<StatisticsProvider *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->deviceChanged(); break;
        case 1: _t->typeChanged(); break;
        case 2: _t->durationChanged(); break;
        case 3: _t->dataChanged(); break;
        case 4: _t->historyAvailableChanged(); break;
        case 5: _t->refresh(); break;
        default: ;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (StatisticsProvider::*)()>(_a, &StatisticsProvider::deviceChanged, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (StatisticsProvider::*)()>(_a, &StatisticsProvider::typeChanged, 1))
            return;
        if (QtMocHelpers::indexOfMethod<void (StatisticsProvider::*)()>(_a, &StatisticsProvider::durationChanged, 2))
            return;
        if (QtMocHelpers::indexOfMethod<void (StatisticsProvider::*)()>(_a, &StatisticsProvider::dataChanged, 3))
            return;
        if (QtMocHelpers::indexOfMethod<void (StatisticsProvider::*)()>(_a, &StatisticsProvider::historyAvailableChanged, 4))
            return;
    }
    if (_c == QMetaObject::ReadProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: *reinterpret_cast<QString*>(_v) = _t->m_device; break;
        case 1: *reinterpret_cast<uint*>(_v) = _t->m_duration; break;
        case 2: *reinterpret_cast<enum HistoryType*>(_v) = _t->m_type; break;
        case 3: *reinterpret_cast<QVariantList*>(_v) = _t->asPoints(); break;
        case 4: *reinterpret_cast<int*>(_v) = _t->count(); break;
        case 5: *reinterpret_cast<int*>(_v) = _t->firstDataPointTime(); break;
        case 6: *reinterpret_cast<int*>(_v) = _t->lastDataPointTime(); break;
        case 7: *reinterpret_cast<int*>(_v) = _t->largestValue(); break;
        case 8: *reinterpret_cast<bool*>(_v) = _t->isHistoryAvailable(); break;
        default: break;
        }
    }
    if (_c == QMetaObject::WriteProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: _t->setDevice(*reinterpret_cast<QString*>(_v)); break;
        case 1: _t->setDuration(*reinterpret_cast<uint*>(_v)); break;
        case 2: _t->setType(*reinterpret_cast<enum HistoryType*>(_v)); break;
        default: break;
        }
    }
}

const QMetaObject *StatisticsProvider::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *StatisticsProvider::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN18StatisticsProviderE_t>.strings))
        return static_cast<void*>(this);
    if (!strcmp(_clname, "QQmlParserStatus"))
        return static_cast< QQmlParserStatus*>(this);
    if (!strcmp(_clname, "org.qt-project.Qt.QQmlParserStatus"))
        return static_cast< QQmlParserStatus*>(this);
    return QObject::qt_metacast(_clname);
}

int StatisticsProvider::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QObject::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 6)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 6;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 6)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 6;
    }
    if (_c == QMetaObject::ReadProperty || _c == QMetaObject::WriteProperty
            || _c == QMetaObject::ResetProperty || _c == QMetaObject::BindableProperty
            || _c == QMetaObject::RegisterPropertyMetaType) {
        qt_static_metacall(this, _c, _id, _a);
        _id -= 9;
    }
    return _id;
}

// SIGNAL 0
void StatisticsProvider::deviceChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 0, nullptr);
}

// SIGNAL 1
void StatisticsProvider::typeChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 1, nullptr);
}

// SIGNAL 2
void StatisticsProvider::durationChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 2, nullptr);
}

// SIGNAL 3
void StatisticsProvider::dataChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 3, nullptr);
}

// SIGNAL 4
void StatisticsProvider::historyAvailableChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 4, nullptr);
}
QT_WARNING_POP
