/****************************************************************************
** Meta object code from reading C++ file 'CommandOutputContext.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.1)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../kinfocenter-6.7.2/src/CommandOutputContext.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'CommandOutputContext.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.1. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN20CommandOutputContextE_t {};
} // unnamed namespace

template <> constexpr inline auto CommandOutputContext::qt_create_metaobjectdata<qt_meta_tag_ZN20CommandOutputContextE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "CommandOutputContext",
        "QML.Element",
        "auto",
        "QML.Creatable",
        "false",
        "QML.UncreatableReason",
        "Only ever passed in from C++",
        "filterChanged",
        "",
        "autoRefreshChanged",
        "autoRefreshMsChanged",
        "textChanged",
        "readyChanged",
        "errorChanged",
        "explanationChanged",
        "refresh",
        "executable",
        "arguments",
        "text",
        "filter",
        "ready",
        "error",
        "explanation",
        "bugReportUrl",
        "QUrl",
        "textFormat",
        "Qt::TextFormat",
        "autoRefreshMs",
        "autoRefresh"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'filterChanged'
        QtMocHelpers::SignalData<void()>(7, 8, QMC::AccessPublic, QMetaType::Void),
        // Signal 'autoRefreshChanged'
        QtMocHelpers::SignalData<void()>(9, 8, QMC::AccessPublic, QMetaType::Void),
        // Signal 'autoRefreshMsChanged'
        QtMocHelpers::SignalData<void()>(10, 8, QMC::AccessPublic, QMetaType::Void),
        // Signal 'textChanged'
        QtMocHelpers::SignalData<void()>(11, 8, QMC::AccessPublic, QMetaType::Void),
        // Signal 'readyChanged'
        QtMocHelpers::SignalData<void()>(12, 8, QMC::AccessPublic, QMetaType::Void),
        // Signal 'errorChanged'
        QtMocHelpers::SignalData<void()>(13, 8, QMC::AccessPublic, QMetaType::Void),
        // Signal 'explanationChanged'
        QtMocHelpers::SignalData<void()>(14, 8, QMC::AccessPublic, QMetaType::Void),
        // Slot 'refresh'
        QtMocHelpers::SlotData<void()>(15, 8, QMC::AccessPublic, QMetaType::Void),
    };
    QtMocHelpers::UintData qt_properties {
        // property 'executable'
        QtMocHelpers::PropertyData<QString>(16, QMetaType::QString, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'arguments'
        QtMocHelpers::PropertyData<QStringList>(17, QMetaType::QStringList, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'text'
        QtMocHelpers::PropertyData<QString>(18, QMetaType::QString, QMC::DefaultPropertyFlags | QMC::Writable, 3),
        // property 'filter'
        QtMocHelpers::PropertyData<QString>(19, QMetaType::QString, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 0),
        // property 'ready'
        QtMocHelpers::PropertyData<bool>(20, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable, 4),
        // property 'error'
        QtMocHelpers::PropertyData<QString>(21, QMetaType::QString, QMC::DefaultPropertyFlags | QMC::Writable, 5),
        // property 'explanation'
        QtMocHelpers::PropertyData<QString>(22, QMetaType::QString, QMC::DefaultPropertyFlags | QMC::Writable, 6),
        // property 'bugReportUrl'
        QtMocHelpers::PropertyData<QUrl>(23, 0x80000000 | 24, QMC::DefaultPropertyFlags | QMC::EnumOrFlag | QMC::Constant),
        // property 'textFormat'
        QtMocHelpers::PropertyData<Qt::TextFormat>(25, 0x80000000 | 26, QMC::DefaultPropertyFlags | QMC::EnumOrFlag | QMC::Constant),
        // property 'autoRefreshMs'
        QtMocHelpers::PropertyData<int>(27, QMetaType::Int, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 2),
        // property 'autoRefresh'
        QtMocHelpers::PropertyData<bool>(28, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 1),
    };
    QtMocHelpers::UintData qt_enums {
    };
    QtMocHelpers::UintData qt_constructors {};
    QtMocHelpers::ClassInfos qt_classinfo({
            {    1,    2 },
            {    3,    4 },
            {    5,    6 },
    });
    return QtMocHelpers::metaObjectData<CommandOutputContext, void>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums, qt_constructors, qt_classinfo);
}
Q_CONSTINIT const QMetaObject CommandOutputContext::staticMetaObject = { {
    QMetaObject::SuperData::link<QObject::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN20CommandOutputContextE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN20CommandOutputContextE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN20CommandOutputContextE_t>.metaTypes,
    nullptr
} };

void CommandOutputContext::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<CommandOutputContext *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->filterChanged(); break;
        case 1: _t->autoRefreshChanged(); break;
        case 2: _t->autoRefreshMsChanged(); break;
        case 3: _t->textChanged(); break;
        case 4: _t->readyChanged(); break;
        case 5: _t->errorChanged(); break;
        case 6: _t->explanationChanged(); break;
        case 7: _t->refresh(); break;
        default: ;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (CommandOutputContext::*)()>(_a, &CommandOutputContext::filterChanged, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (CommandOutputContext::*)()>(_a, &CommandOutputContext::autoRefreshChanged, 1))
            return;
        if (QtMocHelpers::indexOfMethod<void (CommandOutputContext::*)()>(_a, &CommandOutputContext::autoRefreshMsChanged, 2))
            return;
        if (QtMocHelpers::indexOfMethod<void (CommandOutputContext::*)()>(_a, &CommandOutputContext::textChanged, 3))
            return;
        if (QtMocHelpers::indexOfMethod<void (CommandOutputContext::*)()>(_a, &CommandOutputContext::readyChanged, 4))
            return;
        if (QtMocHelpers::indexOfMethod<void (CommandOutputContext::*)()>(_a, &CommandOutputContext::errorChanged, 5))
            return;
        if (QtMocHelpers::indexOfMethod<void (CommandOutputContext::*)()>(_a, &CommandOutputContext::explanationChanged, 6))
            return;
    }
    if (_c == QMetaObject::ReadProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: *reinterpret_cast<QString*>(_v) = _t->executableName(); break;
        case 1: *reinterpret_cast<QStringList*>(_v) = _t->arguments(); break;
        case 2: *reinterpret_cast<QString*>(_v) = _t->m_text; break;
        case 3: *reinterpret_cast<QString*>(_v) = _t->filter(); break;
        case 4: *reinterpret_cast<bool*>(_v) = _t->m_ready; break;
        case 5: *reinterpret_cast<QString*>(_v) = _t->m_error; break;
        case 6: *reinterpret_cast<QString*>(_v) = _t->m_explanation; break;
        case 7: *reinterpret_cast<QUrl*>(_v) = _t->m_bugReportUrl; break;
        case 8: *reinterpret_cast<Qt::TextFormat*>(_v) = _t->m_format; break;
        case 9: *reinterpret_cast<int*>(_v) = _t->m_autoRefreshMs; break;
        case 10: *reinterpret_cast<bool*>(_v) = _t->autoRefresh(); break;
        default: break;
        }
    }
    if (_c == QMetaObject::WriteProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 2:
            if (QtMocHelpers::setProperty(_t->m_text, *reinterpret_cast<QString*>(_v)))
                Q_EMIT _t->textChanged();
            break;
        case 3: _t->setFilter(*reinterpret_cast<QString*>(_v)); break;
        case 4:
            if (QtMocHelpers::setProperty(_t->m_ready, *reinterpret_cast<bool*>(_v)))
                Q_EMIT _t->readyChanged();
            break;
        case 5:
            if (QtMocHelpers::setProperty(_t->m_error, *reinterpret_cast<QString*>(_v)))
                Q_EMIT _t->errorChanged();
            break;
        case 6:
            if (QtMocHelpers::setProperty(_t->m_explanation, *reinterpret_cast<QString*>(_v)))
                Q_EMIT _t->explanationChanged();
            break;
        case 9: _t->setAutoRefreshMs(*reinterpret_cast<int*>(_v)); break;
        case 10: _t->setAutoRefresh(*reinterpret_cast<bool*>(_v)); break;
        default: break;
        }
    }
}

const QMetaObject *CommandOutputContext::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *CommandOutputContext::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN20CommandOutputContextE_t>.strings))
        return static_cast<void*>(this);
    return QObject::qt_metacast(_clname);
}

int CommandOutputContext::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QObject::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 8)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 8;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 8)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 8;
    }
    if (_c == QMetaObject::ReadProperty || _c == QMetaObject::WriteProperty
            || _c == QMetaObject::ResetProperty || _c == QMetaObject::BindableProperty
            || _c == QMetaObject::RegisterPropertyMetaType) {
        qt_static_metacall(this, _c, _id, _a);
        _id -= 11;
    }
    return _id;
}

// SIGNAL 0
void CommandOutputContext::filterChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 0, nullptr);
}

// SIGNAL 1
void CommandOutputContext::autoRefreshChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 1, nullptr);
}

// SIGNAL 2
void CommandOutputContext::autoRefreshMsChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 2, nullptr);
}

// SIGNAL 3
void CommandOutputContext::textChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 3, nullptr);
}

// SIGNAL 4
void CommandOutputContext::readyChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 4, nullptr);
}

// SIGNAL 5
void CommandOutputContext::errorChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 5, nullptr);
}

// SIGNAL 6
void CommandOutputContext::explanationChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 6, nullptr);
}
QT_WARNING_POP
